(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25712,        794]*)
(*NotebookOutlinePosition[     27336,        841]*)
(*  CellTagsIndexPosition[     27254,        835]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["NFourierIntegral", "ObjectName",
  CellTags->"NFourierIntegral"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["NFourierIntegral[", "MR"],
  StyleBox["f", "TI"],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`{\)]],
  StyleBox["t", "TI"],
  StyleBox[",", "MR"],
  StyleBox["a", "TI"],
  StyleBox[",", "MR"],
  StyleBox["b", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`{\)]],
  StyleBox["\[Omega]", "TI"],
  StyleBox[",", "MR"],
  StyleBox["c", "TI"],
  StyleBox[",", "MR"],
  StyleBox["d", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)]],
  StyleBox[",", "MR"],
  StyleBox["m", "TI"],
  StyleBox["]", "MR"],
  " returns a list whose ",
  StyleBox["k", "TI"],
  "th entry is a numerical approximation to the integral ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\@\(2  \[Pi]\)\) \(\[Integral]\_a\%b\( f(
              t)\) \(e\^\(i \( \[Omega]\_k\) t\)\) \[DifferentialD]t\)\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Omega]\_k\), "=", 
          RowBox[{
            StyleBox["c",
              "TI"], "+", 
            StyleBox[
              RowBox[{"\[Gamma]", 
                StyleBox["k",
                  "TI"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = \((d - c)\)/m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] k \[LessEqual] m - 1\)]],
  ". This allows the Fourier integral ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\@\(2  \[Pi]\)\) \(\[Integral]\_a\%b\( f(
              t)\) \(e\^\(i\ \[Omega]\ t\)\) \[DifferentialD]t\)\)]],
  " to be computed at ",
  StyleBox["m", "TI"],
  " equally-spaced points spanning the range ",
  Cell[BoxData[
      \(TraditionalForm\`c \[LessEqual] \[Omega] < d\)]],
  ".\n\[FilledSmallSquare] ",
  StyleBox["NFourierIntegral[", "MR"],
  StyleBox["f", "TI"],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`{\)]],
  Cell[BoxData[
      \(TraditionalForm\`{\)]],
  Cell[BoxData[
      \(TraditionalForm\`t\_1\)]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`}\)]],
  StyleBox[",\[Ellipsis],", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`{\)]],
  Cell[BoxData[
      \(TraditionalForm\`t\_n\)]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  Cell[BoxData[
      \(TraditionalForm\`}\)]],
  Cell[BoxData[
      \(TraditionalForm\`}\)]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`{\)]],
  Cell[BoxData[
      \(TraditionalForm\`{\)]],
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`d\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`}\)]],
  StyleBox[",\[Ellipsis],", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`{\)]],
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`d\_n\)]],
  Cell[BoxData[
      \(TraditionalForm\`}\)]],
  Cell[BoxData[
      \(TraditionalForm\`}\)]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`{\)]],
  Cell[BoxData[
      \(TraditionalForm\`m\_1\)]],
  StyleBox[",", "MR"],
  "\[Ellipsis]",
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`m\_n\)]],
  Cell[BoxData[
      \(TraditionalForm\`}\)]],
  StyleBox["]", "MR"],
  " returns an ",
  StyleBox["n", "TI"],
  "-dimensional array whose ",
  Cell[BoxData[
      \(TraditionalForm\`(\)]],
  Cell[BoxData[
      \(TraditionalForm\`k\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\_2\)]],
  ",\[Ellipsis], ",
  Cell[BoxData[
      \(TraditionalForm\`k\_n\)]],
  Cell[BoxData[
      \(TraditionalForm\`)\)]],
  "th entry is a numerical approximation to the ",
  StyleBox["n", "TI"],
  "-dimensional integral ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((2  \[Pi])\)\^\(\(-n\)/
              2\)\) \(\[Integral]\_\(a\_1\)\%\(b\_1\)\[Ellipsis] \
\(\[Integral]\_\(a\_n\)\%\(b\_n\)\(f(t\_1, \[Ellipsis], t\_n)\) 
                exp[i\ \((\(\[Omega]\_\(k\_1\)\%\((1)\)\) 
                          t\_1 + \[Ellipsis] + \ \
\(\[Omega]\_\(k\_n\)\%\((n)\)\) 
                          t\_n)\)] \[DifferentialD]t\_n  \[Ellipsis] \
\[DifferentialD]t\_1\)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_\(k\_l\)\%\((l)\) = 
        c\_l + \(\[Gamma]\_l\) k\_l\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_l = \((d\_l - c\_l)\)/m\_l\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] k\_l \[LessEqual] m\_l - 1\)]],
  "for all ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] l \[LessEqual] n\)]],
  ".  This allows the ",
  StyleBox["n", "TI"],
  "-dimensional Fourier integral ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((2  \[Pi])\)\^\(\(-n\)/
              2\)\) \(\[Integral]\_\(a\_1\)\%\(b\_1\)\[Ellipsis] \
\(\[Integral]\_\(a\_n\)\%\(b\_n\)\(f(t\_1, \[Ellipsis], t\_n)\) 
                exp[i\ \((\(\[Omega]\^\((1)\)\) 
                          t\_1 + \[Ellipsis] + \ \(\[Omega]\^\((n)\)\) 
                          t\_n)\)] \[DifferentialD]t\_n  \[Ellipsis] \
\[DifferentialD]t\_1\)\)\)]],
  "to be computed at nodes given by the Cartesian product of sets of \
equally-spaced points spanning each coordinate range, where ",
  Cell[BoxData[
      \(TraditionalForm\`m\_l\)]],
  "points span the ",
  StyleBox["l", "TI"],
  "th range ",
  Cell[BoxData[
      \(TraditionalForm\`c\_l \[LessEqual] \[Omega]\^\((l)\) < d\_l\)]],
  ". "
}], "Usage"],

Cell[TextData[{
  "\[FilledSmallSquare] This routine implements the algorithm of Inverarity \
(2002), which in turn generalizes the algorithm of Bailey and Swarztrauber \
(1994).  Essentially, either the rectangular or midpoint rule is used to \
approximate the integral, with the resulting expression being written in the \
form of a circular convolution and evaluated using fast Fourier transforms.  \
A further enhancement to Inverarity (2002) is the use of Richardson \
extrapolation (also known as extrapolation to the limit) to improve \
convergence when the midpoint rule is applied to smooth integrands that are \
finite at their endpoints.\n\[FilledSmallSquare] The following options can be \
given (default values in the second column): \n",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              StyleBox["AccuracyGoal",
                "MR"], 
              StyleBox["Infinity",
                "MR"], "\<\"digits of absolute accuracy sought\"\>"},
            {
              StyleBox["Compiled",
                "MR"], 
              StyleBox["True",
                "MR"], \("whether the integrand should be compiled"\)},
            {
              StyleBox["FourierParameters",
                "MR"], 
              StyleBox[\({0, \ 1}\),
                "MR"], \(defines\ the\ Fourier\ integral\)},
            {
              StyleBox["MaxRecursion",
                "MR"], 
              StyleBox["6",
                "MR"], \("maximum number of recursive subdivisions"\)},
            {
              StyleBox["Method",
                "MR"], 
              StyleBox["Midpoint",
                "MR"], \(quadrature\ rule\ used\)},
            {
              StyleBox["MinRecursion",
                "MR"], 
              StyleBox["0",
                "MR"], \("minimum number of recursive subdivisions "\)},
            {
              StyleBox["PrecisionGoal",
                "MR"], 
              StyleBox["Automatic",
                "MR"], "\<\"digits of precision sought\"\>"}
            }], TraditionalForm]], "3ColumnTable"],
  "\n\[FilledSmallSquare] The options ",
  ButtonBox["AccuracyGoal",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["Compiled",
    ButtonStyle->"RefGuideLink"],
  ", ",
  StyleBox["MaxRecursion", "MR"],
  ", ",
  StyleBox["MinRecursion", "MR"],
  " and ",
  ButtonBox["PrecisionGoal",
    ButtonStyle->"RefGuideLink"],
  " behave as they do in ",
  ButtonBox["NIntegrate",
    ButtonStyle->"RefGuideLink"],
  ", whose documentation should be referred to for further information, \
although the setting ",
  StyleBox["Automatic", "MR"],
  " for ",
  StyleBox["AccuracyGoal", "MR"],
  " and ",
  StyleBox["PrecisionGoal", "MR"],
  " is here interpreted as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["$MachinePrecision",
            "MR"], "-", "10"}], TraditionalForm]]],
  ".\n\[FilledSmallSquare] The option ",
  StyleBox["FourierParameters", "MR"],
  " behaves in a similar manner as in ",
  ButtonBox["FourierTransform",
    ButtonStyle->"RefGuideLink"],
  ".  With the setting ",
  StyleBox["FourierParameters->", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula"],
  StyleBox["r", "TI"],
  StyleBox[",", "MR"],
  StyleBox[" s", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula"],
  " the integral computed by ",
  StyleBox["NFourierIntegral", "MR"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((\(\(|\)\(s\)\(|\)\)\/\((2\ \[Pi])\)\^\(1 - r\))\
\)\^\(n/2\)\) \(\[Integral]\_\(a\_1\)\%\(b\_1\)\[Ellipsis] \(\[Integral]\_\(a\
\_n\)\%\(b\_n\)\(f(t\_1, \[Ellipsis], t\_n)\) 
                exp[i\ \((\(\[Omega]\_\(k\_1\)\%\((1)\)\) 
                          t\_1 + \[Ellipsis] + \ \
\(\[Omega]\_\(k\_n\)\%\((n)\)\) 
                          t\_n)\)] \[DifferentialD]t\_n  \[Ellipsis] \
\[DifferentialD]t\_1\)\)\)]],
  ".\n\[FilledSmallSquare] The option ",
  StyleBox["Method", "MR"],
  " takes the values ",
  StyleBox["Rectangular", "MR"],
  " or ",
  StyleBox["Midpoint", "MR"],
  " and specifies which quadrature rule is used to approximate the integral.\n\
\[FilledSmallSquare] References:\nBailey, D. H. and Swarztrauber, P. N., \"A \
fast method for the numerical evaluation of continuous Fourier and Laplace \
transforms\", ",
  StyleBox["SIAM J. Sci. Comput.",
    FontSlant->"Italic"],
  ", ",
  StyleBox["15",
    FontWeight->"Bold"],
  ", 1105-1110 (1994)\n Inverarity, G. W., \"Fast computation of \
multi-dimensional Fourier integrals\", ",
  StyleBox["SIAM J. Sci. Comput.",
    FontSlant->"Italic"],
  ", in press (2002) \n\[FilledSmallSquare] See also: ",
  ButtonBox["FourierTransform",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["NIntegrate",
    ButtonStyle->"RefGuideLink"],
  ".\n",
  StyleBox["G. W. Inverarity, 3rd May 2002, \[Copyright]British Crown \
Copyright 2002.", "Highlight"]
}], "Notes"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NFourierIntegral"],

Cell[TextData[{
  "Here are some examples that can be evaluated exactly,  starting with ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\@\(2  \[Pi]\)\) \(\[Integral]\_0\%1 
              x\ \(e\^\(i\ k\ x\)\) \[DifferentialD]x\) = \([\((1 - i\ k)\) 
                e\^\(i\ k\) - 1]\)/\((\(\@\(2\ \[Pi]\)\) k\^2)\)\)]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1, \ 5/4, \ 3/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`7/4\)]],
  "."
}], "ExampleText"],

Cell[BoxData[
    \(Needs["\<Calculus`NFourierIntegral`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[approx1 = NFourierIntegral[x, {x, 0, 1}, {1, 2}, 4]]\)], "Input",\

  CellLabel->"In[2]:="],

Cell[BoxData[
    \(NFourierIntegral::"cv" \(\(:\)\(\ \)\) 
      "Prescribed convergence achieved after \!\(3\) iteration(s)."\)], \
"Message",
  CellLabel->"From In[2]:="],

Cell[BoxData[
    \({0.009999999999999981`\ Second, {\(\(0.1523055071786519`\)\(\
\[InvisibleSpace]\)\) + 
          0.12014891956172132`\ \[ImaginaryI], \(\(0.1280580813142804`\)\(\
\[InvisibleSpace]\)\) + 
          0.14166131853903052`\ \[ImaginaryI], \(\(0.10052985204803214`\)\(\
\[InvisibleSpace]\)\) + 
          0.15805014836944298`\ \[ImaginaryI], \(\(0.07082991913783199`\)\(\
\[InvisibleSpace]\)\) + 0.16881498820504762`\ \[ImaginaryI]}}\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["\<\
Compare with the exact solution evaluated at the same points.\
\>", \
"ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(exact = \(\(\((\((1 - \[ImaginaryI]\ #)\) Exp[\[ImaginaryI]\ #] - 1)\)/
              Sqrt[2\ \[Pi]]\)/#^2 &\)@Range[1. , 1.75, 0.25]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({\(\(0.15230550717865693`\)\(\[InvisibleSpace]\)\) + 
        0.12014891956171349`\ \[ImaginaryI], \(\(0.1280580813143083`\)\(\
\[InvisibleSpace]\)\) + 
        0.14166131853899766`\ \[ImaginaryI], \(\(0.10052985204814388`\)\(\
\[InvisibleSpace]\)\) + 
        0.15805014836934397`\ \[ImaginaryI], \(\(0.0708299191381839`\)\(\
\[InvisibleSpace]\)\) + 0.1688149882048154`\ \[ImaginaryI]}\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["\<\
Examine the absolute differences between corresponding \
values.\
\>", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[approx1 - exact]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({9.300603073038237`*^-15, 4.310505232660613`*^-14, 
      1.4929343311673467`*^-13, 4.216171491292695`*^-13}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["\<\
The efficiency of the midpoint rule used together with Richardson \
extrapolation can be contrasted with the failure of the rectangular rule to \
achieve the same accuracy within 13 interval-doubling iterations.\
\>", \
"ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing@
      NFourierIntegral[x, {x, 0, 1}, {1, 2}, 4, Method \[Rule] Rectangular, 
        MaxRecursion \[Rule] 13]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(NFourierIntegral::"nocv" \(\(:\)\(\ \)\) 
      "NFourierIntegral failed to converge after \!\(13\) iteration(s)."\)], \
"Message",
  CellLabel->"From In[5]:="],

Cell[BoxData[
    \({1.76`\ Second, {\(\(0.15230221811502412`\)\(\[InvisibleSpace]\)\) + 
          0.12014379725413021`\ \[ImaginaryI], \(\(0.12805616177056714`\)\(\
\[InvisibleSpace]\)\) + 
          0.14165554175428824`\ \[ImaginaryI], \(\(0.10052942136909433`\)\(\
\[InvisibleSpace]\)\) + 
          0.15804407627636755`\ \[ImaginaryI], \(\(0.07083100409916723`\)\(\
\[InvisibleSpace]\)\) + 0.16880899833308322`\ \[ImaginaryI]}}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "Note that the evaluation time for the rectangular rule can be reduced by \
increasing the setting of ",
  StyleBox["MinRecursion", "MR"],
  ".  This is not the case for the midpoint rule, however, due to the \
recursive structure of Richardson extrapolation."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing@
      NFourierIntegral[x, {x, 0, 1}, {1, 2}, 4, Method \[Rule] Rectangular, 
        MinRecursion \[Rule] 11, MaxRecursion \[Rule] 13]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(NFourierIntegral::"nocv" \(\(:\)\(\ \)\) 
      "NFourierIntegral failed to converge after \!\(13\) iteration(s)."\)], \
"Message",
  CellLabel->"From In[6]:="],

Cell[BoxData[
    \({0.5700000000000003`\ Second, {\(\(0.15230221811502412`\)\(\
\[InvisibleSpace]\)\) + 
          0.12014379725413021`\ \[ImaginaryI], \(\(0.12805616177056714`\)\(\
\[InvisibleSpace]\)\) + 
          0.14165554175428824`\ \[ImaginaryI], \(\(0.10052942136909433`\)\(\
\[InvisibleSpace]\)\) + 
          0.15804407627636755`\ \[ImaginaryI], \(\(0.07083100409916723`\)\(\
\[InvisibleSpace]\)\) + 0.16880899833308322`\ \[ImaginaryI]}}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["\<\
Another way to achieve convergence is to relax the required number \
of digits of relative and/or absolute accuracy.\
\>", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(approx2 = 
      NFourierIntegral[x, {x, 0, 1}, {1, 2}, 4, Method \[Rule] Rectangular, 
        AccuracyGoal \[Rule] 3, MaxRecursion \[Rule] 10]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(NFourierIntegral::"cv" \(\(:\)\(\ \)\) 
      "Prescribed convergence achieved after \!\(7\) iteration(s)."\)], \
"Message",
  CellLabel->"From In[7]:="],

Cell[BoxData[
    \({\(\(0.15209484466984102`\)\(\[InvisibleSpace]\)\) + 
        0.11982126437528147`\ \[ImaginaryI], \(\(0.12793499695292995`\)\(\
\[InvisibleSpace]\)\) + 
        0.14129177199327456`\ \[ImaginaryI], \(\(0.10050198579179945`\)\(\
\[InvisibleSpace]\)\) + 
        0.15766167219107405`\ \[ImaginaryI], \(\(0.07089899458091058`\)\(\
\[InvisibleSpace]\)\) + 0.16843172031257875`\ \[ImaginaryI]}\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[approx2 - exact]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({0.0003895338416831236`, 0.0003895053394650603`, 
      0.0003894743500230284`, 0.0003894427994037418`}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(approx3 = 
      NFourierIntegral[x, {x, 0, 1}, {1, 2}, 4, Method \[Rule] Rectangular, 
        PrecisionGoal \[Rule] 3, MaxRecursion \[Rule] 10]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(NFourierIntegral::"cv" \(\(:\)\(\ \)\) 
      "Prescribed convergence achieved after \!\(10\) iteration(s)."\)], \
"Message",
  CellLabel->"From In[9]:="],

Cell[BoxData[
    \({\(\(0.15227919241353433`\)\(\[InvisibleSpace]\)\) + 
        0.1201079434968648`\ \[ImaginaryI], \(\(0.12804272172046335`\)\(\
\[InvisibleSpace]\)\) + 
        0.1416151065901506`\ \[ImaginaryI], \(\(0.10052640241023167`\)\(\
\[InvisibleSpace]\)\) + 
        0.15800157353903513`\ \[ImaginaryI], \(\(0.07083859379743798`\)\(\
\[InvisibleSpace]\)\) + 0.16876707039621533`\ \[ImaginaryI]}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[approx3 - exact]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({0.0000486980980526157`, 0.00004869765229786278`, 
      0.00004869716769236655`, 0.00004869667436497831`}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
  "The next example shows that endpoint singularities lead to slower \
convergence. Compute ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\(\((2\ \[Pi])\)\^\(-2\)\) \(\[Integral]\
\_\(-1\)\%1\(\[Integral]\_\(-1\)\%1 
                    exp[\(-\(i(
                        x\ t + 
                          y\ u)\)\)]/\@\(\((1 - t\^2)\) \((1 - u\^2)\)\) \
\[DifferentialD]t \[DifferentialD]u\)\)\)\(=\)\)\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`BesselJ[0, x]\ BesselJ[0, \ y]/4\)]],
  " at the 4 nodes formed from the permutations of ",
  Cell[BoxData[
      \(TraditionalForm\`x, \ y = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\)]],
  "."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(approx = 
      NFourierIntegral[
        1/Sqrt[\((1 - t^2)\) \((1 - u^2)\)], {{t, \(-1\), 1}, {u, \(-1\), 
            1}}, {{0, 1}, {0, 1}}, {2, 2}, 
        FourierParameters \[Rule] {\(-1\), \(-1\)}, PrecisionGoal \[Rule] 2, 
        MaxRecursion \[Rule] 10]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(NFourierIntegral::"cv" \(\(:\)\(\ \)\) 
      "Prescribed convergence achieved after \!\(9\) iteration(s)."\)], \
"Message",
  CellLabel->"From In[11]:="],

Cell[BoxData[
    \({{\(\(0.24502309956779406`\)\(\[InvisibleSpace]\)\) + 
          4.960994018625803`*^-17\ \[ImaginaryI], \
\(\(0.23009767125659883`\)\(\[InvisibleSpace]\)\) + 
          4.032529971060881`*^-17\ \[ImaginaryI]}, \
{\(\(0.23009767125659877`\)\(\[InvisibleSpace]\)\) + 
          3.4166883538103397`*^-17\ \[ImaginaryI], \(\(0.21608140488144598`\)\
\(\[InvisibleSpace]\)\) + 
          9.863991727728494`*^-18\ \[ImaginaryI]}}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(exact = 
      N@Apply[BesselJ[0, #1] BesselJ[0, #2]/4 &, 
          Outer[List, {0. , 0.5}, {0. , 0.5}], {2}]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({{0.25`, 0.23461745181020327`}, {0.23461745181020327`, 
        0.2201813947756522`}}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[approx - exact]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({{0.004976900432205944`, 
        0.004519780553604441`}, {0.004519780553604497`, 
        0.004099989894206235`}}\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[TextData[{
  "Finally, compute ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-1\)\%1\(\[Integral]\_\(-2\)\%0\(\
\[Integral]\_0\%2 exp[
                  i(x\ t\  + \ y\ u\  + \ 
                      z\ v)] \[DifferentialD]t \[DifferentialD]u \
\[DifferentialD]v\)\) = 
        8\ \(e\^\(i(x - y)\)\) \(sin(x)\) \(sin(
            y)\) \(sin(z)\)/\((x\ y\ z)\)\)]],
  "at the 8 nodes formed from the permutations of ",
  Cell[BoxData[
      \(TraditionalForm\`x, \ y = 1/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`3/4\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z = 1\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`3/2\)]],
  "."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(approx = 
      NFourierIntegral[
        1, {{t, 0, 2}, {u, \(-2\), 0}, {v, \(-1\), 1}}, {{0.5, 1}, {0.5, 
            1}, {1, 2}}, {2, 2, 2}, 
        FourierParameters \[Rule] {1, 1}]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(NFourierIntegral::"cv" \(\(:\)\(\ \)\) 
      "Prescribed convergence achieved after \!\(4\) iteration(s)."\)], \
"Message",
  CellLabel->"From In[14]:="],

Cell[BoxData[
    \({{{\(\(6.189156342321198`\)\(\[InvisibleSpace]\)\) - 
            9.662757943174515`*^-16\ \[ImaginaryI], \(\(4.8911588826752315`\)\
\(\[InvisibleSpace]\)\) - 
            7.159975057019376`*^-16\ \[ImaginaryI]}, \
{\(\(5.684049233330178`\)\(\[InvisibleSpace]\)\) - 
            1.4513760515534873`\ \[ImaginaryI], \(\(4.491983456141438`\)\(\
\[InvisibleSpace]\)\) - 
            1.1469916857842637`\ \[ImaginaryI]}}, \
{{\(\(5.684049233330178`\)\(\[InvisibleSpace]\)\) + 
            1.4513760515534864`\ \[ImaginaryI], \(\(4.491983456141435`\)\(\
\[InvisibleSpace]\)\) + 
            1.1469916857842648`\ \[ImaginaryI]}, {\(\(5.560516850191307`\)\(\
\[InvisibleSpace]\)\) - 
            1.4896232219067466`*^-15\ \[ImaginaryI], \(\(4.394358435920151`\)\
\(\[InvisibleSpace]\)\) + 
            9.064125413603585`*^-16\ \[ImaginaryI]}}}\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(exact = 
      Apply[8\ Exp[\[ImaginaryI] \((#1 - #2)\)] Sin[#1] Sin[#2] 
            Sin[#3]/\((#1\ #2\ #3)\) &, 
        Outer[List, {0.5, 0.75}, {0.5, 0.75}, {1, 1.5}], {3}]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({{{\(\(6.189156342320891`\)\(\[InvisibleSpace]\)\) + 
            0.`\ \[ImaginaryI], \(\(4.891158882666396`\)\(\[InvisibleSpace]\)\
\) + 0.`\ \[ImaginaryI]}, {\(\(5.684049233329639`\)\(\[InvisibleSpace]\)\) - 
            1.4513760515533485`\ \[ImaginaryI], \(\(4.491983456130951`\)\(\
\[InvisibleSpace]\)\) - 
            1.1469916857815876`\ \[ImaginaryI]}}, {{\(\(5.68404923332964`\)\(\
\[InvisibleSpace]\)\) + 
            1.4513760515533487`\ \[ImaginaryI], \(\(4.491983456130951`\)\(\
\[InvisibleSpace]\)\) + 
            1.1469916857815878`\ \[ImaginaryI]}, {\(\(5.5605168501903615`\)\(\
\[InvisibleSpace]\)\) + 
            0.`\ \[ImaginaryI], \(\(4.394358435906943`\)\(\[InvisibleSpace]\)\
\) + 0.`\ \[ImaginaryI]}}}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[approx - exact]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \({{{3.0642307832936085`*^-13, 
          8.835598948187467`*^-12}, {5.566994800712939`*^-13, 
          1.082278908293929`*^-11}}, {{5.555632336986298`*^-13, 
          1.0820427007006984`*^-11}, {9.459111899124808`*^-13, 
          1.3208101310462069`*^-11}}}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{520, 600},
WindowMargins->{{324, Automatic}, {108, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PageFooters->{{Inherited, Cell[ 
        TextData[ {"\[Copyright]British Crown Copyright 2002"}], 
        "PageFooter"], Inherited}, {Inherited, Cell[ 
        TextData[ {"\[Copyright]British Crown Copyright 2002"}], 
        "PageFooter"], Inherited}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", \
"inverarity", "NFourierIntegral", "mathematica"}, "NFourierIntegral.ps", \
CharacterEncoding -> "ISO8859-1"],
"Magnification"->1},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "NFourierIntegral"->{
    Cell[1705, 50, 70, 1, 32, "ObjectName",
      CellTags->"NFourierIntegral"],
    Cell[12361, 381, 74, 1, 39, "ExampleSection",
      CellTags->"NFourierIntegral"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"NFourierIntegral", 27060, 826}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 70, 1, 32, "ObjectName",
  CellTags->"NFourierIntegral"],
Cell[1778, 53, 5663, 190, 284, "Usage"],
Cell[7444, 245, 4892, 132, 641, "Notes"],

Cell[CellGroupData[{
Cell[12361, 381, 74, 1, 39, "ExampleSection",
  CellTags->"NFourierIntegral"],
Cell[12438, 384, 483, 13, 62, "ExampleText"],
Cell[12924, 399, 96, 2, 26, "Input"],

Cell[CellGroupData[{
Cell[13045, 405, 118, 3, 26, "Input"],
Cell[13166, 410, 173, 4, 37, "Message"],
Cell[13342, 416, 486, 9, 37, "Output"]
}, Open  ]],
Cell[13843, 428, 94, 3, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[13962, 435, 190, 3, 42, "Input"],
Cell[14155, 440, 444, 8, 37, "Output"]
}, Open  ]],
Cell[14614, 451, 95, 3, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[14734, 458, 77, 2, 26, "Input"],
Cell[14814, 462, 166, 3, 23, "Output"]
}, Open  ]],
Cell[14995, 468, 244, 5, 66, "ExampleText"],

Cell[CellGroupData[{
Cell[15264, 477, 174, 4, 42, "Input"],
Cell[15441, 483, 180, 4, 37, "Message"],
Cell[15624, 489, 470, 8, 37, "Output"]
}, Open  ]],
Cell[16109, 500, 297, 6, 66, "ExampleText"],

Cell[CellGroupData[{
Cell[16431, 510, 199, 4, 42, "Input"],
Cell[16633, 516, 180, 4, 37, "Message"],
Cell[16816, 522, 486, 9, 37, "Output"]
}, Open  ]],
Cell[17317, 534, 147, 3, 50, "ExampleText"],

Cell[CellGroupData[{
Cell[17489, 541, 201, 4, 42, "Input"],
Cell[17693, 547, 173, 4, 37, "Message"],
Cell[17869, 553, 447, 8, 37, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18353, 566, 77, 2, 26, "Input"],
Cell[18433, 570, 161, 3, 21, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18631, 578, 202, 4, 42, "Input"],
Cell[18836, 584, 174, 4, 37, "Message"],
Cell[19013, 590, 445, 8, 37, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19495, 603, 78, 2, 26, "Input"],
Cell[19576, 607, 165, 3, 21, "Output"]
}, Open  ]],
Cell[19756, 613, 721, 20, 90, "ExampleText"],

Cell[CellGroupData[{
Cell[20502, 637, 321, 7, 74, "Input"],
Cell[20826, 646, 174, 4, 37, "Message"],
Cell[21003, 652, 482, 9, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21522, 666, 168, 4, 42, "Input"],
Cell[21693, 672, 144, 3, 21, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21874, 680, 77, 2, 26, "Input"],
Cell[21954, 684, 173, 4, 21, "Output"]
}, Open  ]],
Cell[22142, 691, 704, 23, 68, "ExampleText"],

Cell[CellGroupData[{
Cell[22871, 718, 244, 6, 74, "Input"],
Cell[23118, 726, 174, 4, 37, "Message"],
Cell[23295, 732, 895, 17, 73, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24227, 754, 234, 5, 58, "Input"],
Cell[24464, 761, 785, 14, 69, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25286, 780, 77, 2, 26, "Input"],
Cell[25366, 784, 318, 6, 77, "Output"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

